tesserarius
-----------

tesserarius is a collection of invoke tasks that wrap common tools for creating
permissions for a team on the kubernetes cluster.

Installation
------------

To install, use pip::

    pip install tesserarius

Once installed, you can use it from within your project directory. The console
script uses an `tesserarius.yaml` file to configure itself.
